Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3246)

Unified Diff: chrome/browser/ssl/chrome_security_state_model_client.h

Issue 2444383007: Trigger Dangerous indicator for unsafe subresources (Closed)
Patch Set: protip: #include the .h, not the .cc Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ssl/chrome_security_state_model_client.h
diff --git a/chrome/browser/ssl/chrome_security_state_model_client.h b/chrome/browser/ssl/chrome_security_state_model_client.h
index be12ac1b9c20d71addcecb9aef70b68d4a101abb..471ace912fbca302dc854893b45ea5686bb843c3 100644
--- a/chrome/browser/ssl/chrome_security_state_model_client.h
+++ b/chrome/browser/ssl/chrome_security_state_model_client.h
@@ -32,8 +32,9 @@ class ChromeSecurityStateModelClient
void GetSecurityInfo(
security_state::SecurityStateModel::SecurityInfo* result) const;
- // Called when the NavigationEntry's SSLStatus changes.
- void VisibleSSLStateChanged();
+ // Called when the NavigationEntry's SSLStatus or other security
+ // information changes.
+ void VisibleSecurityStateChanged();
// content::WebContentsObserver:
void DidFinishNavigation(

Powered by Google App Engine
This is Rietveld 408576698